## Version 0.6.3

This release includes updates to caching documentation and configuration, as well as improvements to the llamabot feature.

### New Features

- Enhanced caching documentation and configuration: Added a caching section in README.md for configuration and environment variable usage, and updated cache.py to set cache timeout based on an environment variable. (103b7af) (Eric Ma)
- Updated model names and enhanced cache timeout: Added a comprehensive list of model names to ollama\_model\_names.txt, and set a default cache timeout of 1 day in cache.py. (3af5f09) (Eric Ma)

### Bug Fixes

No bug fixes in this release.

### Deprecations

No deprecations in this release.
